ENDPOINTS = {
    "API_ROOT": "https://api.bitkub.com",
    "STATUS_PATH": "/api/status",
    "SERVERTIME_PATH": "/api/v3/servertime",
    "MARKET_SYMBOLS_PATH": "/api/market/symbols",
    "MARKET_TICKER_PATH": "/api/market/ticker?sym={sym}",
    "MARKET_TRADES_PATH": "/api/market/trades?sym={sym}&lmt={lmt}",
    "MARKET_BIDS_PATH": "/api/market/bids?sym={sym}&lmt={lmt}",
    "MARKET_ASKS_PATH": "/api/market/asks?sym={sym}&lmt={lmt}",
    "MARKET_BOOKS_PATH": "/api/market/books?sym={sym}&lmt={lmt}",
    "MARKET_TRADING_VIEW_PATH": "/tradingview/history?symbol={sym}&resolution={int}&from={frm}&to={to}",
    "MARKET_DEPTH_PATH": "/api/market/depth?sym={sym}&lmt={lmt}",

    "MARKET_WALLET": "/api/v3/market/wallet",
    "USER_TRADING_CREDITS": "/api/v3/user/trading-credits",
    "MARKET_PLACE_BID": "/api/v3/market/place-bid",
    "MARKET_PLACE_ASK": "/api/v3/market/place-ask",
    "MARKET_CANCEL_ORDER": "/api/v3/market/cancel-order",
    "MARKET_BALANCES": "/api/v3/market/balances",
    "MARKET_MY_OPEN_ORDERS": "/api/v3/market/my-open-orders?sym={sym}",
    "MARKET_MY_ORDER_HISTORY": "/api/v3/market/my-order-history?sym={sym}&p={p}&lmt={lmt}&start={start}&end={end}",
    "MARKET_ORDER_INFO": "/api/v3/market/order-info?sym={sym}&id={id}&sd={sd}&hash={hash}",
    "CRYPTO_ADDRESSES": "/api/v3/crypto/addresses",
    "CRYPTO_WITHDRAW": "/api/v3/crypto/withdraw",
    "CRYPTO_INTERNAL_WITHDRAW": "/api/v3/crypto/internal-withdraw",
    "CRYPTO_DEPOSIT_HISTORY": "/api/v3/crypto/deposit-history",
    "CRYPTO_WITHDRAW_HISTORY": "/api/v3/crypto/withdraw-history",
    "CRYPTO_GENERATE_ADDRESS": "/api/v3/crypto/generate-address",
    "FIAT_ACCOUNTS": "/api/v3/fiat/accounts",
    "FIAT_WITHDRAW": "/api/v3/fiat/withdraw",
    "FIAT_DEPOSIT_HISTORY": "/api/v3/fiat/deposit-history",
    "FIAT_WITHDRAW_HISTORY": "/api/v3/fiat/withdraw-history",
    "MARKET_WSTOKEN": "/api/v3/market/wstoken",
    "USER_LIMITS": "/api/v3/user/limits",
}



from bitkub import Bitkub
import time

# # v2
# API_KEY = "e8bab6052cb17080bba090c4227615df"
# API_SECRET = "08a30e4b51402d7481cd07fa736c08ac"
# v3
API_KEY = "fc1eb3955c7b6f5007f3cc1be81c9ac8e3d74961db8f07b01ff4fe96c4854fd9"
API_SECRET = "4d43915198944cc488ca04977e8d3749375d0efb9e4e422cb1b531394fd83d92C0dQ7pbG21nJgSLJfzmHueJ8aSl4"


bitkub = Bitkub()
bitkub.set_api_key(API_KEY)
bitkub.set_api_secret(API_SECRET)

balance = bitkub.my_open_orders

coin_name = 'BTC'
symbol = f'THB_{coin_name}'
symbol_v3 = f'{coin_name}_THB'
amountTHB = 15.00

# my_open_orders = bitkub.my_open_orders(sym=symbol_v3)
# print(my_open_orders)

# Get last price
ticker = bitkub.ticker(symbol)
last_price = ticker[symbol]['last']
print(f'Last price: {last_price}')

# Get lowestAsk price
ask_price = ticker[symbol]['lowestAsk']
print(f'Ask price: {ask_price}')

# Get highestBid price
bid_price = ticker[symbol]['highestBid']
print(f'Bid price: {bid_price}')

# buy order
buy_order = bitkub.place_bid(sym=symbol, amt=amountTHB, rat=ask_price)
print(f'Buy order: {buy_order}')

# wait 5 seconds for order to be filled
time.sleep(5)

# get balance
balance = bitkub.balances()
# print(balance)
symbol_balance = balance['result'][coin_name]['available']
print(f'Balance: {symbol_balance}')

# sell order
# sell_order = bitkub.place_ask(sym=symbol, amt=symbol_balance, rat=bid_price)
# print(f'Sell order: {sell_order}')

# sell order by fiat
coinTHB = symbol_balance*bid_price
sell_order = bitkub.place_ask_by_fiat(sym=symbol, amt=coinTHB, rat=bid_price)
print(f'Sell order by fiat: {sell_order}')

# wait 5 seconds for order to be filled
time.sleep(5)

# get balance
balance = bitkub.balances()
symbol_balance = balance['result'][coin_name]['available']
print(f'Balance: {symbol_balance}')


# print(bitkub.crypto_generate_address(sym=symbol))
# print(bitkub.crypto_address())
# print(bitkub.crypto_deposit_history())
# print(bitkub.crypto_withdraw_history())
# print(bitkub.fiat_accounts())
# print(bitkub.fiat_deposit_history())
# print(bitkub.fiat_withdraw_history())



from functools import wraps
from .error import BitkubError


def check_in_attributes(attr_names):
    """
    check if the wrapped function's class have the specified attributes
    :param attr_names: array of attribute names to check
    :return:
    """
    def layer(func):
        @wraps(func)
        def wrapper(self, *args, **kwargs):
            for attr in attr_names:
                if getattr(self, attr, None) is None:
                    raise BitkubError("{0} must be defined".format(attr))
            return func(self, *args, **kwargs)
        return wrapper
    return layer
